@@ -144,14 +144,6 @@ func (self *LocalCommitsController) GetKeybindings(opts types.KeybindingsOpts) [
 			),
 			Description: self.c.Tr.Pick,
 			Tooltip:     self.c.Tr.PickCommitTooltip,
-			// Not displaying this because we only want to display it when a TODO commit
-			// is selected. A keybinding is displayed in the options view if Display is true,
-			// and if it's not disabled, but if we disable it whenever a non-TODO commit is
-			// selected, we'll be preventing pulls from happening within the commits view
-			// (given they both use the 'p' key). Some approaches that come to mind:
-			// * Allow a disabled keybinding to conditionally fallback to a global keybinding
-			// * Allow a separate way of deciding whether a keybinding is displayed in the options view
-			DisplayOnScreen: false,
 		},
 		{
 			Key:               opts.GetKey(opts.Config.Commits.CreateFixupCommit),
@@ -207,14 +199,6 @@ func (self *LocalCommitsController) GetKeybindings(opts types.KeybindingsOpts) [
 			Description:       self.c.Tr.MarkAsBaseCommit,
 			Tooltip:           self.c.Tr.MarkAsBaseCommitTooltip,
 		},
-		// overriding this navigation keybinding because we might need to load
-		// more commits on demand
-		{
-			Key:         opts.GetKey(opts.Config.Universal.GotoBottom),
-			Handler:     self.gotoBottom,
-			Description: self.c.Tr.GotoBottom,
-			Tag:         "navigation",
-		},
 	}
 
 	for _, binding := range outsideFilterModeBindings {
@@ -359,6 +343,10 @@ func (self *LocalCommitsController) fixup(selectedCommits []*models.Commit, star
 }
 
 func (self *LocalCommitsController) reword(commit *models.Commit) error {
+	commitIdx := self.context().GetSelectedLineIdx()
+	if self.c.Git().Config.NeedsGpgSubprocessForCommit() && !self.isHeadCommit(commitIdx) {
+		return errors.New(self.c.Tr.DisabledForGPG)
+	}
 	commitMessage, err := self.c.Git().Commit.GetCommitMessage(commit.Hash())
 	if err != nil {
 		return err
@@ -368,7 +356,7 @@ func (self *LocalCommitsController) reword(commit *models.Commit) error {
 	}
 	self.c.Helpers().Commits.OpenCommitMessagePanel(
 		&helpers.OpenCommitMessagePanelOpts{
-			CommitIndex:      self.context().GetSelectedLineIdx(),
+			CommitIndex:      commitIdx,
 			InitialMessage:   commitMessage,
 			SummaryTitle:     self.c.Tr.Actions.RewordCommit,
 			DescriptionTitle: self.c.Tr.CommitDescriptionTitle,
@@ -404,7 +392,8 @@ func (self *LocalCommitsController) switchFromCommitMessagePanelToEditor(filepat
 		return err
 	}
 
-	return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+	self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+	return nil
 }
 
 func (self *LocalCommitsController) handleReword(summary string, description string) error {
@@ -420,7 +409,8 @@ func (self *LocalCommitsController) handleReword(summary string, description str
 		if err != nil {
 			return err
 		}
-		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+		self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+		return nil
 	})
 }
 
@@ -531,9 +521,8 @@ func (self *LocalCommitsController) edit(selectedCommits []*models.Commit, start
 		return self.c.Helpers().MergeAndRebase.CheckMergeOrRebaseWithRefreshOptions(
 			err,
 			types.RefreshOptions{
-				Mode: types.BLOCK_UI, Then: func() error {
+				Mode: types.BLOCK_UI, Then: func() {
 					self.restoreSelectionRangeAndMode(selectionRangeAndMode)
-					return nil
 				},
 			})
 	}
@@ -559,7 +548,7 @@ func (self *LocalCommitsController) startInteractiveRebaseWithEdit(
 		err := self.c.Git().Rebase.EditRebase(commitsToEdit[len(commitsToEdit)-1].Hash())
 		return self.c.Helpers().MergeAndRebase.CheckMergeOrRebaseWithRefreshOptions(
 			err,
-			types.RefreshOptions{Mode: types.BLOCK_UI, Then: func() error {
+			types.RefreshOptions{Mode: types.BLOCK_UI, Then: func() {
 				todos := make([]*models.Commit, 0, len(commitsToEdit)-1)
 				for _, c := range commitsToEdit[:len(commitsToEdit)-1] {
 					// Merge commits can't be set to "edit", so just skip them
@@ -570,12 +559,11 @@ func (self *LocalCommitsController) startInteractiveRebaseWithEdit(
 				if len(todos) > 0 {
 					err := self.updateTodos(todo.Edit, todos)
 					if err != nil {
-						return err
+						self.c.Log.Errorf("error when updating todos: %v", err)
 					}
 				}
 
 				self.restoreSelectionRangeAndMode(selectionRangeAndMode)
-				return nil
 			}})
 	})
 }
@@ -631,9 +619,7 @@ func (self *LocalCommitsController) pick(selectedCommits []*models.Commit) error
 		return self.updateTodos(todo.Pick, selectedCommits)
 	}
 
-	// at this point we aren't actually rebasing so we will interpret this as an
-	// attempt to pull. We might revoke this later after enabling configurable keybindings
-	return self.pullFiles()
+	panic("should be disabled when not rebasing")
 }
 
 func (self *LocalCommitsController) interactiveRebase(action todo.TodoCommand, startIdx int, endIdx int) error {
@@ -656,9 +642,11 @@ func (self *LocalCommitsController) updateTodos(action todo.TodoCommand, selecte
 		return err
 	}
 
-	return self.c.Refresh(types.RefreshOptions{
+	self.c.Refresh(types.RefreshOptions{
 		Mode: types.SYNC, Scope: []types.RefreshableView{types.REBASE_COMMITS},
 	})
+
+	return nil
 }
 
 func (self *LocalCommitsController) rewordEnabled(commit *models.Commit) *types.DisabledReason {
@@ -695,9 +683,10 @@ func (self *LocalCommitsController) moveDown(selectedCommits []*models.Commit, s
 		}
 		self.context().MoveSelection(1)
 
-		return self.c.Refresh(types.RefreshOptions{
+		self.c.Refresh(types.RefreshOptions{
 			Mode: types.SYNC, Scope: []types.RefreshableView{types.REBASE_COMMITS},
 		})
+		return nil
 	}
 
 	return self.c.WithWaitingStatusSync(self.c.Tr.MovingStatus, func() error {
@@ -718,9 +707,10 @@ func (self *LocalCommitsController) moveUp(selectedCommits []*models.Commit, sta
 		}
 		self.context().MoveSelection(-1)
 
-		return self.c.Refresh(types.RefreshOptions{
+		self.c.Refresh(types.RefreshOptions{
 			Mode: types.SYNC, Scope: []types.RefreshableView{types.REBASE_COMMITS},
 		})
+		return nil
 	}
 
 	return self.c.WithWaitingStatusSync(self.c.Tr.MovingStatus, func() error {
@@ -735,27 +725,20 @@ func (self *LocalCommitsController) moveUp(selectedCommits []*models.Commit, sta
 }
 
 func (self *LocalCommitsController) amendTo(commit *models.Commit) error {
+	var handleCommit func() error
+
 	if self.isSelectedHeadCommit() {
-		self.c.Confirm(types.ConfirmOpts{
-			Title:  self.c.Tr.AmendCommitTitle,
-			Prompt: self.c.Tr.AmendCommitPrompt,
-			HandleConfirm: func() error {
-				return self.c.Helpers().WorkingTree.WithEnsureCommittableFiles(func() error {
-					if err := self.c.Helpers().AmendHelper.AmendHead(); err != nil {
-						return err
-					}
-					return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
-				})
-			},
-		})
-
-		return nil
-	}
-
-	self.c.Confirm(types.ConfirmOpts{
-		Title:  self.c.Tr.AmendCommitTitle,
-		Prompt: self.c.Tr.AmendCommitPrompt,
-		HandleConfirm: func() error {
+		handleCommit = func() error {
+			return self.c.Helpers().WorkingTree.WithEnsureCommittableFiles(func() error {
+				if err := self.c.Helpers().AmendHelper.AmendHead(); err != nil {
+					return err
+				}
+				self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+				return nil
+			})
+		}
+	} else {
+		handleCommit = func() error {
 			return self.c.Helpers().WorkingTree.WithEnsureCommittableFiles(func() error {
 				return self.c.WithWaitingStatus(self.c.Tr.AmendingStatus, func(gocui.Task) error {
 					self.c.LogAction(self.c.Tr.Actions.AmendCommit)
@@ -763,7 +746,17 @@ func (self *LocalCommitsController) amendTo(commit *models.Commit) error {
 					return self.c.Helpers().MergeAndRebase.CheckMergeOrRebase(err)
 				})
 			})
-		},
+		}
+	}
+
+	if self.c.UserConfig().Gui.SkipAmendWarning {
+		return handleCommit()
+	}
+
+	self.c.Confirm(types.ConfirmOpts{
+		Title:         self.c.Tr.AmendCommitTitle,
+		Prompt:        self.c.Tr.AmendCommitPrompt,
+		HandleConfirm: handleCommit,
 	})
 
 	return nil
@@ -816,7 +809,8 @@ func (self *LocalCommitsController) resetAuthor(start, end int) error {
 			return err
 		}
 
-		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+		self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+		return nil
 	})
 }
 
@@ -831,7 +825,8 @@ func (self *LocalCommitsController) setAuthor(start, end int) error {
 					return err
 				}
 
-				return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+				self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+				return nil
 			})
 		},
 	})
@@ -849,7 +844,8 @@ func (self *LocalCommitsController) addCoAuthor(start, end int) error {
 				if err := self.c.Git().Rebase.AddCommitCoAuthor(self.c.Model().Commits, start, end, value); err != nil {
 					return err
 				}
-				return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+				self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+				return nil
 			})
 		},
 	})
@@ -877,14 +873,31 @@ func (self *LocalCommitsController) revert(commits []*models.Commit, start, end
 		HandleConfirm: func() error {
 			self.c.LogAction(self.c.Tr.Actions.RevertCommit)
 			return self.c.WithWaitingStatusSync(self.c.Tr.RevertingStatus, func() error {
+				mustStash := helpers.IsWorkingTreeDirty(self.c.Model().Files)
+
+				if mustStash {
+					if err := self.c.Git().Stash.Push(self.c.Tr.AutoStashForReverting); err != nil {
+						return err
+					}
+				}
+
 				result := self.c.Git().Commit.Revert(hashes, isMerge)
-				if err := self.c.Helpers().MergeAndRebase.CheckMergeOrRebase(result); err != nil {
+				if err := self.c.Helpers().MergeAndRebase.CheckMergeOrRebaseWithRefreshOptions(result, types.RefreshOptions{Mode: types.SYNC}); err != nil {
 					return err
 				}
 				self.context().MoveSelection(len(commits))
-				return self.c.Refresh(types.RefreshOptions{
-					Mode: types.SYNC, Scope: []types.RefreshableView{types.COMMITS, types.BRANCHES},
-				})
+				self.context().FocusLine()
+
+				if mustStash {
+					if err := self.c.Git().Stash.Pop(0); err != nil {
+						return err
+					}
+					self.c.Refresh(types.RefreshOptions{
+						Scope: []types.RefreshableView{types.STASH, types.FILES},
+					})
+				}
+
+				return nil
 			})
 		},
 	})
@@ -920,7 +933,8 @@ func (self *LocalCommitsController) createFixupCommit(commit *models.Commit) err
 							}
 
 							self.context().MoveSelectedLine(1)
-							return self.c.Refresh(types.RefreshOptions{Mode: types.SYNC})
+							self.c.Refresh(types.RefreshOptions{Mode: types.SYNC})
+							return nil
 						})
 					})
 				},
@@ -1020,7 +1034,8 @@ func (self *LocalCommitsController) createAmendCommit(commit *models.Commit, inc
 					}
 
 					self.context().MoveSelectedLine(1)
-					return self.c.Refresh(types.RefreshOptions{Mode: types.SYNC})
+					self.c.Refresh(types.RefreshOptions{Mode: types.SYNC})
+					return nil
 				})
 			},
 			OnSwitchToEditor: nil,
@@ -1146,28 +1161,12 @@ func (self *LocalCommitsController) openSearch() error {
 	// we usually lazyload these commits but now that we're searching we need to load them now
 	if self.context().GetLimitCommits() {
 		self.context().SetLimitCommits(false)
-		if err := self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.COMMITS}}); err != nil {
-			return err
-		}
+		self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.COMMITS}})
 	}
 
 	return self.c.Helpers().Search.OpenSearchPrompt(self.context())
 }
 
-func (self *LocalCommitsController) gotoBottom() error {
-	// we usually lazyload these commits but now that we're jumping to the bottom we need to load them now
-	if self.context().GetLimitCommits() {
-		self.context().SetLimitCommits(false)
-		if err := self.c.Refresh(types.RefreshOptions{Mode: types.SYNC, Scope: []types.RefreshableView{types.COMMITS}}); err != nil {
-			return err
-		}
-	}
-
-	self.context().SetSelectedLineIdx(self.context().Len() - 1)
-
-	return nil
-}
-
 func (self *LocalCommitsController) handleOpenLogMenu() error {
 	return self.c.Menu(types.CreateMenuOptions{
 		Title: self.c.Tr.LogMenuTitle,
@@ -1182,9 +1181,10 @@ func (self *LocalCommitsController) handleOpenLogMenu() error {
 					}
 
 					return self.c.WithWaitingStatus(self.c.Tr.LoadingCommits, func(gocui.Task) error {
-						return self.c.Refresh(
+						self.c.Refresh(
 							types.RefreshOptions{Mode: types.SYNC, Scope: []types.RefreshableView{types.COMMITS}},
 						)
+						return nil
 					})
 				},
 			},
@@ -1234,12 +1234,13 @@ func (self *LocalCommitsController) handleOpenLogMenu() error {
 							self.c.GetAppState().GitLogOrder = value
 							self.c.SaveAppStateAndLogError()
 							return self.c.WithWaitingStatus(self.c.Tr.LoadingCommits, func(gocui.Task) error {
-								return self.c.Refresh(
+								self.c.Refresh(
 									types.RefreshOptions{
 										Mode:  types.SYNC,
 										Scope: []types.RefreshableView{types.COMMITS},
 									},
 								)
+								return nil
 							})
 						}
 					}
@@ -1280,9 +1281,7 @@ func (self *LocalCommitsController) GetOnFocus() func(types.OnFocusOpts) {
 		context := self.context()
 		if context.GetSelectedLineIdx() > COMMIT_THRESHOLD && context.GetLimitCommits() {
 			context.SetLimitCommits(false)
-			self.c.OnWorker(func(_ gocui.Task) error {
-				return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.COMMITS}})
-			})
+			self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.COMMITS}})
 		}
 	}
 }
@@ -1498,8 +1497,7 @@ func (self *LocalCommitsController) pickEnabled(selectedCommits []*models.Commit
 	}
 
 	if !self.isRebasing() {
-		// if not rebasing, we're going to do a pull so we don't care about the selection
-		return nil
+		return &types.DisabledReason{Text: self.c.Tr.PickIsOnlyAllowedDuringRebase, AllowFurtherDispatching: true}
 	}
 
 	return self.midRebaseCommandEnabled(selectedCommits, startIdx, endIdx)
